#
# spec file for package libgig
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
# Copyright (c) 2005-2010 oc2pus
# Copyright (c) 2012 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define soname  6
%define rev     2718
Name:           libgig
Version:        3.3.0+r%{rev}
Release:        1.2
Summary:        C++ library for accessing Gigasampler, DLS, SF, KORG, AKAI files
License:        GPL-2.0+
Group:          System/Libraries
Url:            http://linuxsampler.org/
Source0:        libgig-%{rev}.tar.bz2
#PATCH-FIX-OPENSUSE libdir.patch avvissu@yandex.ru -- Fix error while loading shared libraries
Patch0:         libgig-2718_libdir.patch
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  e2fsprogs-devel
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(audiofile)
BuildRequires:  pkgconfig(flac)
BuildRequires:  pkgconfig(sndfile) >= 1.0.2
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
libgig is a C++ library for reading, modifying and creating Gigasampler /
GigaStudio (.gig) files, DLS (Downloadable Sounds) Level 1/2 files, SoundFont
version 2 (.sf2) and KORG sound files (.KMP and .KSF). These files are
typically used in modern day audio waveform samplers and synthesizer keyboards.

Since the Gigasampler / GigaStudio and DLS formats are based ontop of the
binary RIFF container format, this library also provides convenient access to
RIFF files in general.

This package also contains a Linux/POSIX ported version of libakai, which
provides support for reading Akai formated medias (CDRoms, HDs, Zip disks).
Currently Akai S1000, S01, S2000 and S3000 series are supported.

%package -n     %{name}%{soname}
Summary:        Gigasampler file access library (C++)
Group:          System/Libraries

%description -n %{name}%{soname}
C++ library for accessing Gigasampler, DLS, SF, KORG, AKAI files.

%package        devel
Summary:        Development Headers for libgig
Group:          Development/Languages/C and C++
Requires:       libgig%{soname} = %{version}

%description    devel
This package contains, header files and libraries needed to develop application
that use libgig.

%package        tools
Summary:        Example applications for libgig
Group:          Productivity/Multimedia/Sound/Utilities
Requires:       libgig%{soname} = %{version}
Provides:       libgig6-tools = %{version}
Obsoletes:      libgig6-tools < %{version}

%description    tools
Some example applications for the libgig package.

* akaidump: dump an AKAI media i.e. from a CDROM drive as disk image file to your HD
* akaiextract: txtracts audio samples from an AKAI media or from an AKAI disk image file
* dlsdump: demo app that prints out the content of a DLS file
* gigdump: demo app that prints out the content of a .gig file
* gigmerge: combines multiple .gig files to one .gig file
* gig2mono: converts .gig files from stereo to mono
* gigextract: extracts samples from a .gig file
* korgdump: prints out the content of KORG sound files (.KSF, .KMP)
* korg2gig: converts KORG (.KSF, .KMP) sound files to GigaStudio (.gig) files
* rifftree: tool that prints out the RIFF tree of an arbitrary RIFF file
* sf2dump: prints out the content of a .sf2 file
* etc

%prep
%setup -q -n libgig
%patch0 -p1

%build
[ -e ./configure ] || make -f Makefile.cvs configure
%configure --disable-static 

make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}

#Fix error while loading shared libraries
mv %{buildroot}/%{_libdir}/%{name}/* %{buildroot}/%{_libdir}/
rm -rf %{buildroot}/%{_libdir}/%{name}

find %{buildroot} -type f -name "*.la" -delete -print

%post -n %{name}%{soname} -p /sbin/ldconfig

%postun -n %{name}%{soname} -p /sbin/ldconfig

%files -n %{name}%{soname}
%defattr(-,root,root)
%doc AUTHORS COPYING ChangeLog NEWS README TODO
%{_libdir}/libgig.so.%{soname}*
%{_libdir}/libakai.so.0*

%files devel
%defattr(-,root,root)
%{_includedir}/%{name}
%{_libdir}/libgig.so
%{_libdir}/libakai.so
%{_libdir}/pkgconfig/gig.pc
%{_libdir}/pkgconfig/akai.pc

%files tools
%defattr(-,root,root)
%{_bindir}/akaidump
%{_bindir}/akaiextract
%{_bindir}/dlsdump
%{_bindir}/gig2mono
%{_bindir}/gig2stereo
%{_bindir}/gigmerge
%{_bindir}/korg2gig
%{_bindir}/korgdump
%{_bindir}/gigdump
%{_bindir}/gigextract
%{_bindir}/rifftree
%{_bindir}/sf2dump
%doc %{_mandir}/man1/*.1*

%changelog
* Tue Feb 10 2015 avvissu@yandex.ru
- Update to svn trunk rev 2718:
  * add fork of libakai (this fork provides Linux support) which
    allows reading AKAI medias. Comes with two command line tools
    'akaidump' and 'akaiextract'. Also added a man page for each
    tool;
  * add new command line tool korgdump and gig2mono (and a man
    page for it);
  * add korg2gig (and a man page for it), for
    converting KORG sounds to Giga format;
  * add man page for sf2dump
  * add gigmerge which allows to merge a list of gig files to one
    single gig file;
  * add write support for CtrlTrigger midi rule;
  * add read and write support for Legato and Alternator midi rules;
  * for more information, see the ChangeLog
- Fix error while loading shared libraries (libgig-2718_libdir.patch)
- Use pkgconfig in package names
- Updated description
- Spec file cleanup
* Mon Apr 16 2012 pascal.bleser@opensuse.org
- update to svn trunk rev 2342
* Sat Feb 27 2010 toni@links2linux.de
- update to 3.3.0
* Fri Dec  7 2007 toni@links2linux.de
- update to 3.2.1
* Mon Oct 15 2007 toni@links2linux.de
- update to 3.2.0
* Sun Oct 14 2007 toni@links2linux.de
- update to 3.2.0-cvs20071014
* Sun Oct  7 2007 toni@links2linux.de
- update to 3.1.1-cvs20071006
* Tue Oct  2 2007 toni@links2linux.de
- update to 3.1.1-cvs20071001
* Tue Sep 11 2007 toni@links2linux.de
- update to 3.1.1-cvs20070910
* Fri Aug  3 2007 toni@links2linux.de
- update to 3.1.1-cvs20070802
* Fri Jul  6 2007 toni@links2linux.de
- update to 3.1.1-cvs20070622
* Sun Jun  3 2007 toni@links2linux.de
- update to 3.1.1-cvs20070601
- changed package-layout according new Shared Library Packaging Policy
* Sat May 26 2007 toni@links2linux.de
- update to 3.1.1-cvs20070525
* Sun May 13 2007 toni@links2linux.de
- update to 3.1.1-cvs20070513
* Mon Apr 16 2007 toni@links2linux.de
- update to 3.1.1-cvs20070413
* Sat Mar 24 2007 toni@links2linux.de
- update to 3.1.1-cvs20070324
* Wed Nov 29 2006 toni@links2linux.de
- update to 3.1.0-final
* Fri Nov 24 2006 toni@links2linux.de
- update to 3.1.0-cvs20061124
* Mon Oct 30 2006 toni@links2linux.de
- update to 3.0.0-cvs20061030
* Thu Oct 26 2006 toni@links2linux.de
- update to 3.0.0-cvs20061026
* Fri Oct 20 2006 toni@links2linux.de
- update to 3.0.0-cvs20061019
* Mon Sep 18 2006 toni@links2linux.de
- build for packman
* Sat Sep  2 2006 oc2pus@arcor.de 3.0.0-0.oc2pus.cvs20060902
- update to 3.0.0-cvs20060902
* Sun Aug 20 2006 oc2pus@arcor.de 3.0.0-0.oc2pus.cvs20060820
- update to 3.0.0-cvs20060820
* Fri Aug 11 2006 oc2pus@arcor.de 3.0.0-0.oc2pus.cvs20060811
- update to 3.0.0-cvs20060811
* Sat Jul 22 2006 oc2pus@arcor.de 3.0.0-0.oc2pus.cvs20060722
- update to 3.0.0-cvs20060722
* Thu Jun  1 2006 oc2pus@arcor.de 3.0.0-0.oc2pus.cvs20060601
- update to 3.0.0-cvs20060601
* Sun May 14 2006 oc2pus@arcor.de 3.0.0-0.oc2pus.cvs20060514
- update to 3.0.0-cvs20060514
* Sat May  6 2006 oc2pus@arcor.de 3.0.0-0.oc2pus.cvs20060506
- update to 3.0.0-cvs20060506
* Sun Apr 30 2006 oc2pus@arcor.de 3.0.0-0.oc2pus.1
- update to 3.0.0
* Fri Mar  3 2006 oc2pus@arcor.de 2.0.2-0.oc2pus.cvs20060303
- update to cvs20060303
* Mon Dec 26 2005 oc2pus@arcor.de 2.0.2-0.oc2pus.cvs20051226
- update to cvs20051226
* Thu Dec 22 2005 oc2pus@arcor.de 2.0.2-0.oc2pus.cvs20051222
- update to cvs20051222
* Fri Nov 25 2005 oc2pus@arcor.de 2.0.2-0.oc2pus.cvs20051125
- update to cvs20051125
* Tue Nov 22 2005 oc2pus@arcor.de 2.0.2-0.oc2pus.cvs20051122
- update to cvs20051122
* Thu Nov 17 2005 oc2pus@arcor.de 2.0.2-0.oc2pus.cvs20051117
- update to cvs20051117
* Sat Nov 12 2005 oc2pus@arcor.de 2.0.2-0.oc2pus.cvs20051112
- update to cvs20051112
* Fri Nov  4 2005 oc2pus@arcor.de 2.0.2-0.oc2pus.cvs20051104
- update to cvs20051104
* Mon Sep 26 2005 oc2pus@arcor.de 2.0.2-0.oc2pus.cvs20050926
- update to cvs20050917
* Sat Sep 17 2005 oc2pus@arcor.de 2.0.2-0.oc2pus.cvs20050917
- update to cvs20050917
- changes in spec-file for build on x86_64
* Wed Aug 17 2005 oc2pus@arcor.de 2.0.2-0.oc2pus.cvs20050816
- update to cvs20050816
* Tue Aug  2 2005 oc2pus@arcor.de 2.0.1-0.oc2pus.cvs20050726
- update to cvs20050726
* Mon Jul 18 2005 oc2pus@arcor.de 2.0.1-0.oc2pus.cvs20050718
- update to cvs20050718
* Sun Jun 19 2005 oc2pus@arcor.de 2.0.1-0.oc2pus.cvs20050619
- update to cvs20050619
* Mon Jun 13 2005 oc2pus@arcor.de 2.0.1-0.oc2pus.cvs20050613
- update to cvs20050613
* Tue Jun  7 2005 oc2pus@arcor.de 2.0.0-0.oc2pus.cvs20050607
- update to cvs20050607
* Mon Jun  6 2005 oc2pus@arcor.de 2.0.0-0.oc2pus.cvs20050606
- update to cvs20050606
* Wed May 18 2005 oc2pus@arcor.de 2.0.0-0.oc2pus.cvs20050518
- update to cvs20050518
* Mon May  9 2005 oc2pus@arcor.de 2.0.0-0.oc2pus.cvs20050509
- update to cvs20050509
- removed Patch
* Sun May  8 2005 oc2pus@arcor.de 1.0.0-0.oc2pus.cvs20050508
- update to cvs20050508
- included Patch for VERSION/PACKAGE
* Thu May  5 2005 oc2pus@arcor.de 1.0.0-0.oc2pus.cvs20050505
- update to cvs20050505
* Tue May  3 2005 oc2pus@arcor.de 1.0.0-0.oc2pus.cvs20050503
- update to cvs20050503
- added audiofile to Requires/BuildRequires
* Mon Mar  7 2005 oc2pus@arcor.de 1.0.0-0.oc2pus.1
- build for SuSE
- little modifications using RPM-macros
* Wed Nov 24 2004 rncbc@users.sourceforge.net
- prepared for 1.0.0
* Sat Jul 10 2004 cuse@users.sourceforge.net
- renamed 'libgig.pc' to 'gig.pc' as well as the pkg-config lib name
* Fri Jul  2 2004 rncbc@users.sourceforge.net
- Created and corrected initial libgig.spec
